@@ -544,16 +544,16 @@ def read_diag_coded_type_from_odx(et_element, doc_frags: List[OdxDocFragment]):
     dct_type = et_element.get(f"{xsi}type")
     bit_length = None
     if dct_type == "LEADING-LENGTH-INFO-TYPE":
-        bit_length = int(et_element.find("BIT-LENGTH").text)
+        bit_length = int(et_element.findtext("BIT-LENGTH"))
         return LeadingLengthInfoType(base_data_type,
                                      bit_length=bit_length,
                                      base_type_encoding=base_type_encoding,
                                      is_highlow_byte_order=is_highlow_byte_order)
     elif dct_type == "MIN-MAX-LENGTH-TYPE":
-        min_length = int(et_element.find("MIN-LENGTH").text)
+        min_length = int(et_element.findtext("MIN-LENGTH"))
         max_length = None
         if et_element.find("MAX-LENGTH"):
-            max_length = int(et_element.find("MAX-LENGTH").text)
+            max_length = int(et_element.findtext("MAX-LENGTH"))
         termination = et_element.get("TERMINATION")
 
         return MinMaxLengthType(base_data_type,
@@ -578,10 +578,10 @@ def read_diag_coded_type_from_odx(et_element, doc_frags: List[OdxDocFragment]):
                                    base_type_encoding=base_type_encoding,
                                    is_highlow_byte_order=is_highlow_byte_order)
     elif dct_type == "STANDARD-LENGTH-TYPE":
-        bit_length = int(et_element.find("BIT-LENGTH").text)
+        bit_length = int(et_element.findtext("BIT-LENGTH"))
         bit_mask = None
         if et_element.find("BIT-MASK"):
-            bit_mask = et_element.find("BIT-MASK").text
+            bit_mask = et_element.findtext("BIT-MASK")
         condensed = et_element.get("CONDENSED") == "true"
         return StandardLengthType(base_data_type,
                                   bit_length,
