@@ -1,7 +1,7 @@
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2022 MBition GmbH
 
-from typing import TYPE_CHECKING, Any, List, Union
+from typing import TYPE_CHECKING, List, Union
 
 from .utils import read_description_from_odx
 from .odxlink import OdxLinkRef, OdxLinkId, OdxDocFragment, OdxLinkDatabase
@@ -114,18 +114,17 @@ def read_end_of_pdu_field_from_odx(et_element, doc_frags: List[OdxDocFragment])
     -> EndOfPduField:
     odx_id = OdxLinkId.from_et(et_element, doc_frags)
     assert odx_id is not None
-    short_name = et_element.find("SHORT-NAME").text
+    short_name = et_element.findtext("SHORT-NAME")
     long_name = et_element.findtext("LONG-NAME")
     description = read_description_from_odx(et_element.find("DESC"))
 
     structure_ref = OdxLinkRef.from_et(et_element.find("BASIC-STRUCTURE-REF"), doc_frags)
-    assert structure_ref is not None
-    structure_snref = None
 
+    structure_snref = None
     if et_element.find("BASIC-STRUCTURE-SNREF") is not None:
-        structure_ref = None
         structure_snref = et_element.find(
             "BASIC-STRUCTURE-SNREF").get("SHORT-NAME")
+    assert (structure_ref is not None) or (structure_snref is not None)
 
     if et_element.find("ENV-DATA-DESC-REF") is not None:
         structure_ref = OdxLinkRef.from_et(et_element.get("ENV-DATA-DESC-REF"), doc_frags)
@@ -137,12 +136,12 @@ def read_end_of_pdu_field_from_odx(et_element, doc_frags: List[OdxDocFragment])
 
     if et_element.find("MIN-NUMBER-OF-ITEMS") is not None:
         min_number_of_items = int(
-            et_element.find("MIN-NUMBER-OF-ITEMS").text)
+            et_element.findtext("MIN-NUMBER-OF-ITEMS"))
     else:
         min_number_of_items = None
     if et_element.find("MAX-NUMBER-OF-ITEMS") is not None:
         max_number_of_items = int(
-            et_element.find("MAX-NUMBER-OF-ITEMS").text)
+            et_element.findtext("MAX-NUMBER-OF-ITEMS"))
     else:
         max_number_of_items = None
 
